from __future__ import absolute_import, division, print_function

from telnyx.api_resources.abstract import DeletableAPIResource


class MessagingHostedNumber(
    DeletableAPIResource,
):
    OBJECT_NAME = "messaging_hosted_number"



from __future__ import absolute_import, division, print_function

import telnyx

TEST_FAX_CONNECTION_ID = "0239852093"
TEST_SRC_LONG_CODE = "+13125550100"
TEST_DST = "+17735550100"
TEST_MEDIA_URL = "http://www.africau.edu/images/default/sample.pdf"


class TestFax(object):
    def test_can_create_standard_fax(self, request_mock):
        resource = telnyx.Fax.create(
            from_=TEST_SRC_LONG_CODE,
            to=TEST_DST,
            media_url=TEST_MEDIA_URL,
            connection_id=TEST_FAX_CONNECTION_ID,
        )
        request_mock.assert_requested("post", "/v2/faxes")
        print(resource)
        print(type(resource))
        assert isinstance(resource, telnyx.Fax)



from __future__ import absolute_import, division, print_function

import telnyx

TEST_RESOURCE_ID = "6a09cdc3-8948-47f0-aa62-74ac943d6c58"


class TestIPConnection(object):
    def test_is_listable(self, request_mock):
        resources = telnyx.IPConnection.list()
        request_mock.assert_requested("get", "/v2/ip_connections")
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], telnyx.IPConnection)

    def test_is_retrievable(self, request_mock):
        resource = telnyx.IPConnection.retrieve(TEST_RESOURCE_ID)
        request_mock.assert_requested("get", "/v2/ip_connections/%s" % TEST_RESOURCE_ID)
        assert isinstance(resource, telnyx.IPConnection)

    def test_is_creatable(self, request_mock):
        resource = telnyx.IPConnection.create()
        request_mock.assert_requested("post", "/v2/ip_connections")
        assert isinstance(resource, telnyx.IPConnection)

    def test_is_saveable(self, request_mock):
        ip_connection = telnyx.IPConnection.retrieve(TEST_RESOURCE_ID)
        ip_connection.active = False
        resource = ip_connection.save()
        request_mock.assert_requested(
            "patch", "/v2/ip_connections/%s" % TEST_RESOURCE_ID
        )
        assert isinstance(resource, telnyx.IPConnection)
        assert resource is ip_connection

    def test_is_modifiable(self, request_mock):
        resource = telnyx.IPConnection.modify(TEST_RESOURCE_ID, active=False)
        request_mock.assert_requested(
            "patch", "/v2/ip_connections/%s" % TEST_RESOURCE_ID
        )
        assert isinstance(resource, telnyx.IPConnection)

    def test_is_deletable(self, request_mock):
        resource = telnyx.IPConnection.retrieve(TEST_RESOURCE_ID)
        resource.delete()
        request_mock.assert_requested(
            "delete", "/v2/ip_connections/%s" % TEST_RESOURCE_ID
        )



from __future__ import absolute_import, division, print_function

import sys
from collections import namedtuple

from telnyx import util
from telnyx.six.moves import builtins

PRINT_FUNC_STRING = builtins.__name__ + ".print"

LogTestCase = namedtuple("LogTestCase", "env flag should_output")
FmtTestCase = namedtuple("FmtTestCase", "props expected")


class TestUtil(object):
    DUMMY_REQ_ID = "req_qsxPhqHyLxcoaM"

    def log_test_loop(self, test_cases, logging_func, logger_name, mocker):
        for case in test_cases:
            try:
                logger_mock = mocker.patch(logger_name)
                print_mock = mocker.patch(PRINT_FUNC_STRING)
                mocker.patch("telnyx.log", case.flag)
                mocker.patch("telnyx.util.TELNYX_LOG", case.env)

                logging_func("foo \nbar", y=3)  # function under test

                if case.should_output:
                    print_mock.assert_called_once_with(
                        "message='foo \\nbar' y=3", file=sys.stderr
                    )
                else:
                    print_mock.assert_not_called()
                logger_mock.assert_called_once_with("message='foo \\nbar' y=3")
            finally:
                mocker.stopall()

    def test_log_debug(self, mocker):
        # (TELNYX_LOG, telnyx.log): should_output?
        test_cases = [
            LogTestCase(env=None, flag=None, should_output=False),
            LogTestCase(env=None, flag="debug", should_output=True),
            LogTestCase(env=None, flag="info", should_output=False),
            LogTestCase(env="debug", flag=None, should_output=True),
            LogTestCase(env="debug", flag="debug", should_output=True),
            LogTestCase(env="debug", flag="info", should_output=False),
            LogTestCase(env="info", flag=None, should_output=False),
            LogTestCase(env="info", flag="debug", should_output=True),
            LogTestCase(env="info", flag="info", should_output=False),
        ]
        self.log_test_loop(
            test_cases,
            logging_func=util.log_debug,
            logger_name="telnyx.util.logger.debug",
            mocker=mocker,
        )

    def test_log_info(self, mocker):
        # (TELNYX_LOG, telnyx.log): should_output?
        test_cases = [
            LogTestCase(env=None, flag=None, should_output=False),
            LogTestCase(env=None, flag="debug", should_output=True),
            LogTestCase(env=None, flag="info", should_output=True),
            LogTestCase(env="debug", flag=None, should_output=True),
            LogTestCase(env="debug", flag="debug", should_output=True),
            LogTestCase(env="debug", flag="info", should_output=True),
            LogTestCase(env="info", flag=None, should_output=True),
            LogTestCase(env="info", flag="debug", should_output=True),
            LogTestCase(env="info", flag="info", should_output=True),
        ]
        self.log_test_loop(
            test_cases,
            logging_func=util.log_info,
            logger_name="telnyx.util.logger.info",
            mocker=mocker,
        )

    def test_logfmt(self):
        cases = [
            FmtTestCase(
                props={"foo": "bar", "message": "yes"}, expected="foo=bar message=yes"
            ),
            FmtTestCase(props={"foo": "bar baz"}, expected="foo='bar baz'"),
            FmtTestCase(props={"b": 2, "a": 1, "c": 3}, expected="a=1 b=2 c=3"),
            FmtTestCase(
                props={"key with space": True}, expected="'key with space'=True"
            ),
        ]
        for case in cases:
            result = util.logfmt(case.props)
            assert result == case.expected



from __future__ import absolute_import, division, print_function

import pytest

import telnyx

TEST_RESOURCE_ID = "123"


class TestPhoneNumberRegulatoryRequirement(object):
    def test_is_listable(self, request_mock):
        resources = telnyx.PhoneNumberRegulatoryRequirement.list()
        request_mock.assert_requested(
            "get", "/v2/phone_numbers_regulatory_requirements"
        )
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], telnyx.PhoneNumberRegulatoryRequirement)

    def test_is_retrievable(self, request_mock):
        with pytest.raises(telnyx.error.InvalidRequestError):
            telnyx.PhoneNumberRegulatoryRequirement.retrieve(TEST_RESOURCE_ID)
